@@ -184,13 +184,20 @@ class CommandLineInterface:
             func = self._cname_2_func[result['command']]
         # FIXME: we take '--help' as the most important option to check. the
         #   '--help' is the only global option for now.
+        if not result['args'] and not result['kwargs']:
+            if self.commands[id(func)]['args'] \
+                    or self.commands[id(func)]['kwargs']:
+                result['kwargs'][':help'] = True
         if result['kwargs'].get(':help'):
             self.show(func)
         elif result['kwargs'].get(':helpx'):
-            self.show2()
-            # self.show(None)
-            # for func_info in self.commands.values():
-            #     self.show(func_info['func'])
+            if func:
+                self.show(func)
+            else:
+                self.show2()
+                # # self.show(None)
+                # # for func_info in self.commands.values():
+                # #     self.show(func_info['func'])
         else:
             self.exec(func, result['args'], result['kwargs'])
     
